* 1/27/2024
* Yoo Sun Jung & Yohan Park: SSQ R&R 
* Winners and losers in U.S.–China trade disputes
* Figures in the main text

clear all
set maxvar 32000
capture cd "C:/Users/`c(username)'/Dropbox/SSQ-Special_Issue_2024"
capture cd "/Users/yoosunjung/Dropbox (Yoo Sun Jung)/SSQ-Special_Issue_2024"

//dis runiform(1, 10) : for generation of seed number




*=======================================*
**# I. Main model (Host: China)
* 6 groups: US, EU, East Asia, India, Other Americas, & Rest of the World
*=======================================*
* DV: greenfield inflow to China, number of projects made by countries of investing firms to Chinese manufaccturing sector (quarterly)
* Shock: number of WTO disputes between US and China in last 3 years 
* Controls: political constraints (V-DEM),  GDPPC(logged), Population(logged), and growth rate.
* 6 Home country groups: US, EU, East Asia (Japan, S.Korea, Taiwan), India, Americas (except US) & Rest of the World

clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )



// Figure 1: effectsplot	



matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge)  mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `" "Americas" "(except US)" "' 3 "India" 4 "East Asia" 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.2 0.2 )) xlabel(-0.2 (0.05) 0.2) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 


	
graph export "figures/effects_UScomp_China.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		
		

		

		
	

*=======================================*
**# II. Different grouping: Top 20 investing  (Host: China)
* US / EU / SK, Taiwan, Japan, Singapore / Indonesia, India, Saudi Arabia, Kurait, South Africa / Canada, Switzerland / ROW

*=======================================*

clear all

set seed 70501481
use "data/CHN_homecty_top20cty_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

* Model 3
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det    // ongoing disputes in last three years
* ldv model 
local x1 v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4  
dynsimpie `x1'  , dvs(ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)   time(5) range(20)  ar(1)



// Figure 2: effectsplot

capture drop ep_*
matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

capture gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge) mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `""Developing" "Economies" "in Top 20" "' 3 `""Canada &" "Switzerland" "'  4 `""Advanced" "Economies" "in East Asia" "' 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.1 0.12 )) xlabel(-0.1 (0.05) 0.1) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}



local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 

graph export "figures/effects_top20_UScomp_China.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		
		







*======================*
**# 3. VMP
* DV: greenfield inflow to China, number of projects made by countries of investing firms to Chinese manufaccturing sector (quarterly)
* Shock: number of WTO disputes between US and China in last 3 years 
* Controls: political constraints (V-DEM),  GDPPC(logged), Population(logged) and growth rate
*6 Home country groups: US, EU, East Asia (Japan, S.Korea, Taiwan), India, Americas (except US) & Rest of the World
*======================*

clear all
set seed 70501481

use "data/VMP_homecty_7g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal_tot LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/7 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_vmp_7g ratio_NP1 ratio_NP7 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal_tot_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4  
dynsimpie `x1' , dvs($dv_vmp_7g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )

//effectsplot


// Figure 3: effectsplot

capture drop ep_*
matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..7, 13]
matrix ep_lr = ep_mat[1..7, 14]

matrix ep_sr_lb95 = ep_mat[1..7, 3]
matrix ep_sr_ub95 = ep_mat[1..7, 4]
matrix ep_sr_lb90 = ep_mat[1..7, 5]
matrix ep_sr_ub90 = ep_mat[1..7, 6]

matrix ep_lr_lb95 = ep_mat[1..7, 7]
matrix ep_lr_ub95 = ep_mat[1..7, 8]
matrix ep_lr_lb90 = ep_mat[1..7, 9]
matrix ep_lr_ub90 = ep_mat[1..7, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

capture gen sort = _n if _n <=7 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mcolor(cranberry) msize(medlarge) mlabcolor(gs5)   mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 "Taiwan" 3 "Japan"  4 "South Korea"  5 "EU" 6 "China" 7 "US", ang(h)) ///
		xscale(range(-0.2 0.3 )) xlabel(-0.2 (0.1) 0.3) xline(0) legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 

graph export "figures/effects_UScomp_VMP.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		


