* 1/27/2024
* Yoo Sun Jung & Yohan Park: SSQ R&R 
* Winners and losers in U.S.–China trade disputes
* SUR regression tables in Supplementary Information


clear all
set maxvar 32000
capture cd "C:/Users/`c(username)'/Dropbox/SSQ-Special_Issue_2024"
capture cd "/Users/yoosunjung/Dropbox (Yoo Sun Jung)/SSQ-Special_Issue_2024"

//dis runiform(1, 10) : for seed number


*=======================================*
**# I. Main model (Host: China)
* 6 groups: US, EU, East Asia, India, Other Americas, & Rest of the World
*=======================================*
* DV: greenfield inflow to China, number of projects made by countries of investing firms to Chinese manufaccturing sector (quarterly)
* Shock: number of WTO disputes between US and China in last 3 years 
* Controls: political constraints (V-DEM),  GDPPC(logged), Population(logged) growth rate, dispute dummies between China and EU, Japan, Rest of the World, or Americas 
*6 Home country groups: US, EU, East Asia (Japan, S.Korea, Taiwan), India, Americas (except US) & Rest of the World

 
clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}
 
		gen ratio_NP2_ratio_NP1 = ln(ratio_NP2/ratio_NP1)
		gen ratio_NP3_ratio_NP1 = ln(ratio_NP3/ratio_NP1)
		gen ratio_NP4_ratio_NP1 = ln(ratio_NP4/ratio_NP1)
		gen ratio_NP5_ratio_NP1 = ln(ratio_NP5/ratio_NP1)
		gen ratio_NP6_ratio_NP1 = ln(ratio_NP6/ratio_NP1)

sureg (ratio_NP2_ratio_NP1 L.ratio_NP2_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4) ///
(ratio_NP3_ratio_NP1 L.ratio_NP3_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4) ///
(ratio_NP4_ratio_NP1 L.ratio_NP4_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4)  ///
(ratio_NP5_ratio_NP1 L.ratio_NP5_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4) ///
(ratio_NP6_ratio_NP1 L.ratio_NP6_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4)
  
est store A
global coeflabel  	us_jksum_t3 "Number of disputes (US-China)" ///
	v2x_liberal2_t4 "Political constraints" LogGDPPC_host_t4 "GDPpc (host, logged)" ///
	GROWTH_host_t4 "Growth (host, annual \%)" LogPOP_host_t4 "Population (host, logged)" ///
	L.ratio_NP6_ratio_NP1 "Lagged Dependent Variable" ///
	L.ratio_NP5_ratio_NP1 "Lagged Dependent Variable" ///
	L.ratio_NP4_ratio_NP1 "Lagged Dependent Variable"  ///
	L.ratio_NP3_ratio_NP1 "Lagged Dependent Variable"  ///	
	L.ratio_NP2_ratio_NP1 "Lagged Dependent Variable"  	
	

local order L.ratio_NP2_ratio_NP1 L.ratio_NP3_ratio_NP1 L.ratio_NP4_ratio_NP1 ///
L.ratio_NP5_ratio_NP1 L.ratio_NP6_ratio_NP1 ///
us_jksum_t3 LogGDPPC_host_t4 GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4
esttab A  using "tables/tab_chn_sureg_raw.tex",   ///
 b(%9.3f) se(%9.3f) unstack order(`order') coeflabels($coeflabel) scalars(r2  N) sfmt(%12.3f) ///
 label compress nonotes nogaps replace star(* 0.1 ** 0.05 *** 0.01) nonumbers ///
  mtitles("(1)" "(2)" "(3)" "(4)" "(5)")  ///
 nobaselevels  
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
		
	

*=======================================*
**# II. Different grouping: Top 20 investing  (Host: China)
* US / EU / SK, Taiwan, Japan, Singapore / Indonesia, India, Saudi Arabia, Kurait, South Africa / Canada, Switzerland / ROW

*=======================================*

clear all
//dis runiform(1, 10)

set seed 70501481
use "data/CHN_homecty_top20cty_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}


	gen ratio_NP2_ratio_NP1 = ln(ratio_NP2/ratio_NP1)
		gen ratio_NP3_ratio_NP1 = ln(ratio_NP3/ratio_NP1)
		gen ratio_NP4_ratio_NP1 = ln(ratio_NP4/ratio_NP1)
		gen ratio_NP5_ratio_NP1 = ln(ratio_NP5/ratio_NP1)
		gen ratio_NP6_ratio_NP1 = ln(ratio_NP6/ratio_NP1)

sureg (ratio_NP2_ratio_NP1 L.ratio_NP2_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4) ///
(ratio_NP3_ratio_NP1 L.ratio_NP3_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4) ///
(ratio_NP4_ratio_NP1 L.ratio_NP4_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4)  ///
(ratio_NP5_ratio_NP1 L.ratio_NP5_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4) ///
(ratio_NP6_ratio_NP1 L.ratio_NP6_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4)
  
est store A
global coeflabel  	us_jksum_t3 "Number of disputes (US-China)" ///
	v2x_liberal2_t4 "Political constraints" LogGDPPC_host_t4 "GDPpc (host, logged)" ///
	GROWTH_host_t4 "Growth (host, annual \%)" LogPOP_host_t4 "Population (host, logged)" ///
	L.ratio_NP6_ratio_NP1 "Lagged Dependent Variable" ///
	L.ratio_NP5_ratio_NP1 "Lagged Dependent Variable" ///
	L.ratio_NP4_ratio_NP1 "Lagged Dependent Variable"  ///
	L.ratio_NP3_ratio_NP1 "Lagged Dependent Variable"  ///	
	L.ratio_NP2_ratio_NP1 "Lagged Dependent Variable"  	
	

local order L.ratio_NP2_ratio_NP1 L.ratio_NP3_ratio_NP1 L.ratio_NP4_ratio_NP1 ///
L.ratio_NP5_ratio_NP1 L.ratio_NP6_ratio_NP1 ///
us_jksum_t3 LogGDPPC_host_t4 GROWTH_host_t4 LogPOP_host_t4 v2x_liberal2_t4
esttab A  using "tables/tab_chn_top20_sureg_raw.tex",   ///
 b(%9.3f) se(%9.3f) unstack order(`order') coeflabels($coeflabel) scalars(r2  N) sfmt(%12.3f) ///
 label compress nonotes nogaps replace star(* 0.1 ** 0.05 *** 0.01) nonumbers ///
  mtitles("(1)" "(2)" "(3)" "(4)" "(5)")  ///
 nobaselevels  
 
 
 
 













*======================*
**# 4. VMP
* DV: greenfield inflow to China, number of projects made by countries of investing firms to Chinese manufaccturing sector (quarterly)
* Shock: number of WTO disputes between US and China in last 3 years 
* Controls: political constraints (V-DEM),  GDPPC(logged), Population(logged) growth rate, dispute dummies between China and EU, Japan, Rest of the World, or Americas 
*6 Home country groups: US, EU, East Asia (Japan, S.Korea, Taiwan), India, Americas (except US) & Rest of the World
*======================*

clear all
set seed 70501481

use "data/VMP_homecty_7g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal_tot LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/7 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}
	gen ratio_NP2_ratio_NP1 = ln(ratio_NP2/ratio_NP1)
		gen ratio_NP3_ratio_NP1 = ln(ratio_NP3/ratio_NP1)
		gen ratio_NP4_ratio_NP1 = ln(ratio_NP4/ratio_NP1)
		gen ratio_NP5_ratio_NP1 = ln(ratio_NP5/ratio_NP1)
		gen ratio_NP6_ratio_NP1 = ln(ratio_NP6/ratio_NP1)
		gen ratio_NP7_ratio_NP1 = ln(ratio_NP7/ratio_NP1)

sureg (ratio_NP2_ratio_NP1 L.ratio_NP2_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal_tot_t4) ///
(ratio_NP3_ratio_NP1 L.ratio_NP3_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal_tot_t4) ///
(ratio_NP4_ratio_NP1 L.ratio_NP4_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal_tot_t4)  ///
(ratio_NP5_ratio_NP1 L.ratio_NP5_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal_tot_t4) ///
(ratio_NP6_ratio_NP1 L.ratio_NP6_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal_tot_t4) ///
 (ratio_NP7_ratio_NP1 L.ratio_NP7_ratio_NP1 us_jksum_t3  ///
  LogGDPPC_host_t4  GROWTH_host_t4 LogPOP_host_t4 v2x_liberal_tot_t4)
  
est store A
global coeflabel  	us_jksum_t3 "Number of disputes (US-China)" ///
	v2x_liberal_tot_t4 "Political constraints" LogGDPPC_host_t4 "GDPpc (host, logged)" ///
	GROWTH_host_t4 "Growth (host, annual \%)" LogPOP_host_t4 "Population (host, logged)" ///
	L.ratio_NP6_ratio_NP1 "Lagged Dependent Variable" ///
	L.ratio_NP5_ratio_NP1 "Lagged Dependent Variable" ///
	L.ratio_NP4_ratio_NP1 "Lagged Dependent Variable"  ///
	L.ratio_NP3_ratio_NP1 "Lagged Dependent Variable"  ///	
	L.ratio_NP2_ratio_NP1 "Lagged Dependent Variable"  	L.ratio_NP7_ratio_NP1 "Lagged Dependent Variable"
	

local order L.ratio_NP2_ratio_NP1 L.ratio_NP3_ratio_NP1 L.ratio_NP4_ratio_NP1 ///
L.ratio_NP5_ratio_NP1 L.ratio_NP6_ratio_NP1 L.ratio_NP7_ratio_NP1 ///
us_jksum_t3 LogGDPPC_host_t4 GROWTH_host_t4 LogPOP_host_t4 v2x_liberal_tot_t4
esttab A  using "tables/tab_vmp_sureg_raw.tex",   ///
 b(%9.3f) se(%9.3f) unstack order(`order') coeflabels($coeflabel) scalars(r2  N) sfmt(%12.3f) ///
 label compress nonotes nogaps replace star(* 0.1 ** 0.05 *** 0.01) nonumbers ///
  mtitles("(1)" "(2)" "(3)" "(4)" "(5)" "(6)")  ///
 nobaselevels  
 
 



