* Winners and losers in U.S.–China trade disputes
* Supplementary Information 


clear all
set maxvar 32000
capture cd "C:/Users/`c(username)'/Dropbox/SSQ-Special_Issue_2024/JP_ssq_replication"
capture cd "/Users/yoosunjung/Dropbox (Yoo Sun Jung)/SSQ-Special_Issue_2024/JP_ssq_replication"

//dis runiform(1, 10) : for seed number


*=======================================*
**# I. Change-from-baseline Plots 
*=======================================*
* 1. Main model (Host: China)
* 6 groups: US, EU, East Asia, India, Other Americas, & Rest of the World

clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta", clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )




// (1) cfbplot

//matrix list e(cfbplot)

forvalues i = 1/6 {
capture drop gr`i'_cfb_* 
matrix cfb_mat = e(cfbplot)
matrix gr`i'_cfb_mid = cfb_mat[1..20, `i'+13]
matrix gr`i'_cfb_lb95 = cfb_mat[1..20, `i'*2]
matrix gr`i'_cfb_ub95 = cfb_mat[1..20, `i'*2+1]

svmat gr`i'_cfb_mid, names(gr`i'_cfb_mid)
svmat gr`i'_cfb_lb95, names(gr`i'_cfb_lb95)
svmat gr`i'_cfb_ub95, names(gr`i'_cfb_ub95)

}
matrix at = cfb_mat[1..20, 1]
svmat at, names(at)

forvalues i = 1/6 {
local 1 "Rest of the World"
local 2 "Americas (except US)"
local 3 "India"
local 4 "East Asia (South Korea, Taiwan, and Japan)"
local 5 "EU"
local 6 "US"
graph twoway (rcap gr`i'_cfb_lb95 gr`i'_cfb_ub95 at1 , mcolor(none) lcolor(gray) lpattern(solid) msize(0 ) )  ///
		(scatter gr`i'_cfb_mid at1,  plotr(m(b 4)) ms(O) mlabcolor(gs5)  mcolor(cranberry) msize(medlarge) mlabpos(6) legend(off) graphregion(color(white)) bgcolor(white)) , /// 
		legend(off) xlabel(0 (5) 20) yscale(range(0 1 )) ylabel(0 (0.2) 1) ///
		ytitle("") ///
		xtitle("") 	///
		title("``i''", position(12)) saving("figures/cfb_`i'.gph", replace)
}


local figlist ""
forvalues i = 6 (-1) 1 {
local figlist `figlist' "figures/cfb_`i'.gph"
}
graph combine  `figlist',  l1title("Expected Proportion") b1title("Time (quarter)") ///
	col(3) graphregion(color(white))  ysize(4) xsize(9)

graph export "figures/cfb_UScomp_China.pdf" , replace 

forvalues i = 1/6 {
rm  "figures/cfb_`i'.gph"
}




* 2. Different grouping: Top 20 investing  (Host: China)
* US / EU / SK, Taiwan, Japan, Singapore / Indonesia, India, Saudi Arabia, Kurait, South Africa / Canada, Switzerland / ROW



clear all

set seed 70501481
use "data/CHN_homecty_top20cty_mfg_qr.dta", clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

* Model 3
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det    // ongoing disputes in last three years
* ldv model 
local x1 v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4  
dynsimpie `x1'  , dvs(ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)   time(5) range(20)  ar(1)







forvalues i = 1/6 {
capture drop gr`i'_cfb_* 
matrix cfb_mat = e(cfbplot)
matrix gr`i'_cfb_mid = cfb_mat[1..20, `i'+13]
matrix gr`i'_cfb_lb95 = cfb_mat[1..20, `i'*2]
matrix gr`i'_cfb_ub95 = cfb_mat[1..20, `i'*2+1]

svmat gr`i'_cfb_mid, names(gr`i'_cfb_mid)
svmat gr`i'_cfb_lb95, names(gr`i'_cfb_lb95)
svmat gr`i'_cfb_ub95, names(gr`i'_cfb_ub95)

}
matrix at = cfb_mat[1..20, 1]
capture svmat at, names(at)

forvalues i = 1/6 {
local 1 "Rest of the World"
local 2 "Developing Economies in Top 20"
local 3 "Canada & Switzerland"
local 4 "Advanced Economies in East Asia"
local 5 "EU"
local 6 "US"
graph twoway (rcap gr`i'_cfb_lb95 gr`i'_cfb_ub95 at1 , mcolor(none) lcolor(gray) lpattern(solid) msize(0 ) )  ///
		(scatter gr`i'_cfb_mid at1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge) mlabpos(6) legend(off) graphregion(color(white)) bgcolor(white)) , /// 
		legend(off) xlabel(0 (5) 20) yscale(range(0 1 )) ylabel(0 (0.2) 1) ///
		ytitle("") ///
		xtitle("") 	///
		title("``i''", position(12)) saving("figures/cfb_`i'.gph", replace)
}


local figlist ""
forvalues i = 6 (-1) 1 {
local figlist `figlist' "figures/cfb_`i'.gph"
}
graph combine  `figlist',  l1title("Expected Proportion") b1title("Time (quarter)") ///
	col(3) graphregion(color(white))  ysize(4) xsize(9)

graph export "figures/cfb_top20_UScomp_China.pdf" , replace 
forvalues i = 1/6 {
rm  "figures/cfb_`i'.gph"
}









* 3. VMP


clear all
set seed 70501481

use "data/VMP_homecty_7g_mfg_qr.dta" , clear

tsset quarter
foreach x in v2x_liberal_tot LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/7 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_vmp_7g ratio_NP1 ratio_NP7 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal_tot_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4  
dynsimpie `x1' , dvs($dv_vmp_7g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )

forvalues i = 1/7 {
capture drop gr`i'_cfb_* 
matrix cfb_mat = e(cfbplot)
matrix gr`i'_cfb_mid = cfb_mat[1..20, `i'+15]
matrix gr`i'_cfb_lb95 = cfb_mat[1..20, `i'*2]
matrix gr`i'_cfb_ub95 = cfb_mat[1..20, `i'*2+1]

svmat gr`i'_cfb_mid, names(gr`i'_cfb_mid)
svmat gr`i'_cfb_lb95, names(gr`i'_cfb_lb95)
svmat gr`i'_cfb_ub95, names(gr`i'_cfb_ub95)

}
matrix at = cfb_mat[1..20, 1]
capture svmat at, names(at)

forvalues i = 1/7 {
local 1 "Rest of the World"
local 2 "Taiwan"
local 3 "Japan"
local 4 "South Korea"
local 5 "EU"
local 6 "China"
local 7 "US"
graph twoway (rcap gr`i'_cfb_lb95 gr`i'_cfb_ub95 at1 , mcolor(none) lcolor(gray) lpattern(solid) msize(0 ) )  ///
		(scatter gr`i'_cfb_mid at1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge) mlabpos(6) legend(off) graphregion(color(white)) bgcolor(white)) , /// 
		legend(off) xlabel(0 (5) 20) yscale(range(0 1 )) ylabel(0 (0.2) 1) ///
		ytitle("") ///
		xtitle("") 	///
		title("``i''", position(12)) saving("figures/cfb_`i'.gph", replace)
}


local figlist ""
forvalues i = 7 (-1) 1 {
local figlist `figlist' "figures/cfb_`i'.gph"
}
graph combine  `figlist',  l1title("Expected Proportion") b1title("Time (quarter)") ///
	col(4) graphregion(color(white))  ysize(4) xsize(9)
graph export "figures/cfb_UScomp_VMP.pdf" , replace 

forvalues i = 1/7 {
rm  "figures/cfb_`i'.gph"
}
















*=======================================*
**# II. Robustness Checks
*=======================================*
* 1. Add year trend 

// (1) linear trend


clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta" , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 year
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )


/*
Calculate p-value 
matrix ep_mat = e(effectsplot)

matrix list ep_mat


dis (.03541778 + .00115504 )/1.64  // se

dis .03541778 /.0223005   // get z-score
1.5882056  // get z-score

*/	
	
	

// Figure 1: effectsplot	



matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge)  mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `" "Americas" "(except US)" "' 3 "India" 4 "East Asia" 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.2 0.2 )) xlabel(-0.2 (0.05) 0.2) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 


	
graph export "figures/effects_UScomp_China_yrlin.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		
		
		
		

// (2) Quadratic term


clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
gen year_sq = year*year
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 year year_sq
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )



// Figure 1: effectsplot	



matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge)  mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `" "Americas" "(except US)" "' 3 "India" 4 "East Asia" 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.2 0.2 )) xlabel(-0.2 (0.05) 0.2) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 


	
graph export "figures/effects_UScomp_China_yrsq.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}				




* 2. Trade volume 

// (1) US - China trade volume 

clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta" , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

 foreach x in _us_chn _chn {
 gen LogTRADE`x'_t4 = l4.LogTRADE`x'
 }

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 LogTRADE_us_chn_t4
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )



// Figure 1: effectsplot	



matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge)  mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `" "Americas" "(except US)" "' 3 "India" 4 "East Asia" 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.2 0.2 )) xlabel(-0.2 (0.05) 0.2) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 


	
graph export "figures/effects_UScomp_China_uschn_trade.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		
		


// (2) US - China trade volume 

clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

 foreach x in _us_chn _chn {
 gen LogTRADE`x'_t4 = l4.LogTRADE`x'
 }

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 LogTRADE_chn_t4
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 )



// Figure 1: effectsplot	



matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge)  mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `" "Americas" "(except US)" "' 3 "India" 4 "East Asia" 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.2 0.2 )) xlabel(-0.2 (0.05) 0.2) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 


	
graph export "figures/effects_UScomp_China_chn_trade.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		
		
		
		
		
		
* 3. Different shock: 2


clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

 foreach x in _us_chn _chn {
 gen LogTRADE`x'_t4 = l4.LogTRADE`x'
 }

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals( 2 ) sigs(95 90)  time(5) range(20)  ar(1 )



// Figure 1: effectsplot	



matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge)  mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `" "Americas" "(except US)" "' 3 "India" 4 "East Asia" 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.2 0.2 )) xlabel(-0.2 (0.05) 0.2) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 


	
graph export "figures/effects_UScomp_China_difshock.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		
	
		
	
	
	
		

*=======================================*
**# III. AR (2) models 
*=======================================*

* 1. China Dataset

clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_main_6g ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4 
dynsimpie `x1' , dvs($dv_main_6g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar(1 2)

 

// (1) cfbplot

//matrix list e(cfbplot)

forvalues i = 1/6 {
capture drop gr`i'_cfb_* 
matrix cfb_mat = e(cfbplot)
matrix gr`i'_cfb_mid = cfb_mat[1..20, `i'+13]
matrix gr`i'_cfb_lb95 = cfb_mat[1..20, `i'*2]
matrix gr`i'_cfb_ub95 = cfb_mat[1..20, `i'*2+1]

svmat gr`i'_cfb_mid, names(gr`i'_cfb_mid)
svmat gr`i'_cfb_lb95, names(gr`i'_cfb_lb95)
svmat gr`i'_cfb_ub95, names(gr`i'_cfb_ub95)

}
matrix at = cfb_mat[1..20, 1]
svmat at, names(at)

forvalues i = 1/6 {
local 1 "Rest of the World"
local 2 "Americas (except US)"
local 3 "India"
local 4 "East Asia (South Korea, Taiwan, and Japan)"
local 5 "EU"
local 6 "US"
graph twoway (rcap gr`i'_cfb_lb95 gr`i'_cfb_ub95 at1 , mcolor(none) lcolor(gray) lpattern(solid) msize(0 ) )  ///
		(scatter gr`i'_cfb_mid at1,  plotr(m(b 4)) ms(O) mlabcolor(gs5)  mcolor(cranberry) msize(medlarge) mlabpos(6) legend(off) graphregion(color(white)) bgcolor(white)) , /// 
		legend(off) xlabel(0 (5) 20) yscale(range(0 1 )) ylabel(0 (0.2) 1) ///
		ytitle("") ///
		xtitle("") 	///
		title("``i''", position(12)) saving("figures/cfb_`i'.gph", replace)
}


local figlist ""
forvalues i = 6 (-1) 1 {
local figlist `figlist' "figures/cfb_`i'.gph"
}
graph combine  `figlist',  l1title("Expected Proportion") b1title("Time (quarter)") ///
	col(3) graphregion(color(white))  ysize(4) xsize(9)

graph export "figures/cfb_UScomp_China_ar2.pdf" , replace 

forvalues i = 1/6 {
rm  "figures/cfb_`i'.gph"
}


// (2) effectsplot	



matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..6, 13]
matrix ep_lr = ep_mat[1..6, 14]

matrix ep_sr_lb95 = ep_mat[1..6, 3]
matrix ep_sr_ub95 = ep_mat[1..6, 4]
matrix ep_sr_lb90 = ep_mat[1..6, 5]
matrix ep_sr_ub90 = ep_mat[1..6, 6]

matrix ep_lr_lb95 = ep_mat[1..6, 7]
matrix ep_lr_ub95 = ep_mat[1..6, 8]
matrix ep_lr_lb90 = ep_mat[1..6, 9]
matrix ep_lr_ub90 = ep_mat[1..6, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

gen sort = _n if _n <=6 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge)  mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 `" "Americas" "(except US)" "' 3 "India" 4 "East Asia" 5 "EU" 6 "US", ang(h)) ///
		xscale(range(-0.2 0.2 )) xlabel(-0.2 (0.05) 0.2) xline(0)  legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 


	
graph export "figures/effects_UScomp_China_ar2.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		
		

		

		
	

* 2. VMP dataset


clear all
set seed 70501481

use "data/VMP_homecty_7g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal_tot LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/7 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}

global dv_vmp_7g ratio_NP1 ratio_NP7 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2
 
 
 
* Model 1
* Shock: US-China trade disputes (US: complainant vs. China: respondent)
sum us_jksum_t3, det   // ongoing disputes in last three years 
* ldv model 
local x1  v2x_liberal_tot_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4  
dynsimpie `x1' , dvs($dv_vmp_7g) ///
	shockvars(us_jksum_t3) shockvals(`r(sd)') sigs(95 90)  time(5) range(20)  ar( 1 2)

effectsplot


// (1) effectsplot

capture drop ep_*
matrix ep_mat = e(effectsplot)
matrix ep_sr = ep_mat[1..7, 13]
matrix ep_lr = ep_mat[1..7, 14]

matrix ep_sr_lb95 = ep_mat[1..7, 3]
matrix ep_sr_ub95 = ep_mat[1..7, 4]
matrix ep_sr_lb90 = ep_mat[1..7, 5]
matrix ep_sr_ub90 = ep_mat[1..7, 6]

matrix ep_lr_lb95 = ep_mat[1..7, 7]
matrix ep_lr_ub95 = ep_mat[1..7, 8]
matrix ep_lr_lb90 = ep_mat[1..7, 9]
matrix ep_lr_ub90 = ep_mat[1..7, 10]

svmat ep_sr, names(ep_sr)
svmat ep_lr, names(ep_lr)

svmat ep_sr_lb95, names(ep_sr_lb95)
svmat ep_sr_ub95, names(ep_sr_ub95)
svmat ep_sr_lb90, names(ep_sr_lb90)
svmat ep_sr_ub90, names(ep_sr_ub90)

svmat ep_lr_lb95, names(ep_lr_lb95)
svmat ep_lr_ub95, names(ep_lr_ub95)
svmat ep_lr_lb90, names(ep_lr_lb90)
svmat ep_lr_ub90, names(ep_lr_ub90)

capture gen sort = _n if _n <=7 
gen at_sr = sort 
gen at_lr = sort 

		
foreach x in sr lr {

local sr "Short-run"
local lr "Long-run"

local sr2 off 
local lr2 order(1 "95% CI" 2 "90% CI") ring(0) position(3) bplacement(3) bmargin(small) row(2) size(small) symxsize(4)

graph twoway (rcap ep_`x'_lb95 ep_`x'_ub95 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(medium ) msize(0 ))  ///
		(rcap ep_`x'_lb90 ep_`x'_ub90 at_`x' , horizontal mcolor(none) lcolor(gray)  lpattern(solid) lwidth(thick ) msize(0 ))  ///
		(scatter  at_`x' ep_`x'1,  plotr(m(b 4)) ms(O) mcolor(cranberry) msize(medlarge) mlabcolor(gs5)   mlabpos(6)  graphregion(color(white)) bgcolor(white)) , /// 
		ylabel(1 `""Rest of" "the World" "' 2 "Taiwan" 3 "Japan"  4 "South Korea"  5 "EU" 6 "China" 7 "US", ang(h)) ///
		xscale(range(-0.2 0.3 )) xlabel(-0.2 (0.1) 0.3) xline(0) legend(``x'2' ) ///
		ytitle("") ///
		xtitle("Expected Proportion Change from Baseline") 	///
		title("``x''", position(12))	saving("figures/ep_`x'.gph", replace)

}


local figlist ""
foreach x in sr lr {
local figlist `figlist' "figures/ep_`x'.gph"
}
graph combine  `figlist',  ///
	col(2) graphregion(color(white))  ysize(4) xsize(9) 

graph export "figures/effects_UScomp_VMP_ar2.pdf" , replace 	

foreach x in sr lr {
rm  "figures/ep_`x'.gph"
}		





* cfbplot



forvalues i = 1/7 {
capture drop gr`i'_cfb_* 
matrix cfb_mat = e(cfbplot)
matrix gr`i'_cfb_mid = cfb_mat[1..20, `i'+15]
matrix gr`i'_cfb_lb95 = cfb_mat[1..20, `i'*2]
matrix gr`i'_cfb_ub95 = cfb_mat[1..20, `i'*2+1]

svmat gr`i'_cfb_mid, names(gr`i'_cfb_mid)
svmat gr`i'_cfb_lb95, names(gr`i'_cfb_lb95)
svmat gr`i'_cfb_ub95, names(gr`i'_cfb_ub95)

}
matrix at = cfb_mat[1..20, 1]
capture svmat at, names(at)

forvalues i = 1/7 {
local 1 "Rest of the World"
local 2 "Taiwan"
local 3 "Japan"
local 4 "South Korea"
local 5 "EU"
local 6 "China"
local 7 "US"
graph twoway (rcap gr`i'_cfb_lb95 gr`i'_cfb_ub95 at1 , mcolor(none) lcolor(gray) lpattern(solid) msize(0 ) )  ///
		(scatter gr`i'_cfb_mid at1,  plotr(m(b 4)) ms(O) mlabcolor(gs5) mcolor(cranberry) msize(medlarge) mlabpos(6) legend(off) graphregion(color(white)) bgcolor(white)) , /// 
		legend(off) xlabel(0 (5) 20) yscale(range(0 1 )) ylabel(0 (0.2) 1) ///
		ytitle("") ///
		xtitle("") 	///
		title("``i''", position(12)) saving("figures/cfb_`i'.gph", replace)
}


local figlist ""
forvalues i = 7 (-1) 1 {
local figlist `figlist' "figures/cfb_`i'.gph"
}
graph combine  `figlist',  l1title("Expected Proportion") b1title("Time (quarter)") ///
	col(4) graphregion(color(white))  ysize(4) xsize(9)
graph export "figures/cfb_UScomp_VMP_ar2.pdf" , replace 

forvalues i = 1/7 {
rm  "figures/cfb_`i'.gph"
}






*=======================================*
**# IV. Stationary Test
*=======================================*
* 1. Main model (Host: China)
* 6 groups: US, EU, East Asia, India, Other Americas, & Rest of the World

clear all
set seed 70501481

use "data/CHN_homecty_6g_mfg_qr.dta"  , clear

tsset quarter
foreach x in v2x_liberal2 LogGDPPC_host LogPOP_host GROWTH_host  { 
gen `x'_t4 = l4.`x'
}

foreach x in CAP NP JOB {
egen total_`x' = rowtotal(`x'*)
}

foreach x in CAP NP JOB {
forvalues i = 1/6 {
gen ratio_`x'`i' = `x'`i'/total_`x'
}
}



* Stationary Test
//Augmented Dickey-Fuller & Phillips–Perron(1988) tests for unit root 
//For both tests, the null hypothesis is that the series has a unit root.

local ylist ratio_NP1 ratio_NP6 ratio_NP5 ratio_NP4 ratio_NP3 ratio_NP2

foreach i of varlist `ylist'{
	dfuller `i'
	pperron `i'
}
//All dvs in ylist are stationary! 
//No need to test cointegration given that all dependent variables time series are stationary. We use Lagged DV model! 

//Shock variable
dfuller us_jksum_t3  //Notice: NON-STATIONARY
gen us_jksum_t3D =D.us_jksum_t3  //first differencing a time series of us_jksum_t3
dfuller us_jksum_t3D   //Stationary

//Controls 
local xlist v2x_liberal2_t4 LogGDPPC_host_t4 LogPOP_host_t4 GROWTH_host_t4
 foreach i of varlist `xlist'{
 	dfuller `i'
 	gen `i'D = D.`i'
	dfuller `i'D
} 
//For all ivs in xlist, they are nonstationary in levels, but stationary in its first differences.

